ajdmom.ito\_mom
===============

.. automodule:: ajdmom.ito_mom

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      c_nmi
      coef_poly
      int_et
      int_mIEI
      int_mIEII
      moment_IEI
      moment_IEII
      moment_v
      recursive_IEI
      recursive_IEII
   
   

   
   
   

   
   
   



